@@ -257,6 +257,9 @@ class ClUpdateAction(Action):
          'method': 'Update.save_with_bdeps()',
          'essential': False
          },
+        {'name': 'update_fastlogin_domain',
+         'method': "Update.update_fastlogin_domain_path()"
+        },
         {'name': 'premerge_group',
          'group': __("Checking for updates"),
          'tasks': [
