@@ -33,7 +33,7 @@ from calculate.lib.configparser import ConfigParser
 from calculate.lib.cl_lang import setLocalTranslate
 from calculate.lib.utils.text import simplify_profiles, _u8
 from calculate.lib.utils.git import Git, GitError
-from calculate.lib.utils.portage import ReposConf
+from calculate.lib.utils.portage import ReposConf, PortageState
 from ..profile import (RepositoryStorageSet, DEFAULT_BRANCH,
                        LocalStorage, ProfileRepository, CacheStorage)
 
@@ -378,6 +378,20 @@ class VariableClUpdateLastTimestamp(ReadonlyVariable):
         return ini.getVar('system', 'last_update') or "0"
 
 
+class VariableClUpdateSettingsChangesSet(Variable):
+    """
+    Определить были ли изменения в /etc/portage, /var/log/emerge.log
+    """
+    type = Variable.Types.Boolean
+
+    def get(self):
+        ini = SystemIni(self.parent)
+        old_portage_state_hash = ini.getVar('system', 'portage_hash') or ""
+        ps = PortageState()
+        new_portage_state_hash = ps.get_state()
+        return "on" if new_portage_state_hash != old_portage_state_hash else "off"
+
+
 class VariableClUpdateBranchName(Variable):
     """
     Список доступных репозиторием
